Versions
========

**This should not be considered a complete list of versions**

.. contents::

Update v1.2.4
-------------

First release that is finally available on PyPi.

Main new feature: custom trackers! You can now add any tracker you want
by implementing a simple tracker class. See the
`manual <https://github.com/SchmollerLab/Cell_ACDC/blob/main/UserManual/Cell-ACDC_User_Manual.pdf>`__
at the section “**Adding trackers to the pipeline**”.

Additionally, this release includes many UI/UX improvements such as
color and style customisation, alongside a inverted LUTs.